==> aws-java-sdk-waf-1.10.62-sources.jar: com/amazonaws/services/waf/model/transform/HTTPHeaderJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.waf.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * HTTPHeaderMarshaller
 */
public class HTTPHeaderJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(HTTPHeader hTTPHeader, SdkJsonGenerator jsonGenerator) {
        if (hTTPHeader == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (hTTPHeader.getName() != null) {
                jsonGenerator.writeFieldName("Name").writeValue(
                        hTTPHeader.getName());
            }
            if (hTTPHeader.getValue() != null) {
                jsonGenerator.writeFieldName("Value").writeValue(
                        hTTPHeader.getValue());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static HTTPHeaderJsonMarshaller instance;

    public static HTTPHeaderJsonMarshaller getInstance() {
        if (instance == null)
            instance = new HTTPHeaderJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-waf-1.10.69-sources.jar: com/amazonaws/services/waf/model/transform/HTTPHeaderJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.waf.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * HTTPHeaderMarshaller
 */
public class HTTPHeaderJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(HTTPHeader hTTPHeader,
            StructuredJsonGenerator jsonGenerator) {

        if (hTTPHeader == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (hTTPHeader.getName() != null) {
                jsonGenerator.writeFieldName("Name").writeValue(
                        hTTPHeader.getName());
            }
            if (hTTPHeader.getValue() != null) {
                jsonGenerator.writeFieldName("Value").writeValue(
                        hTTPHeader.getValue());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static HTTPHeaderJsonMarshaller instance;

    public static HTTPHeaderJsonMarshaller getInstance() {
        if (instance == null)
            instance = new HTTPHeaderJsonMarshaller();
        return instance;
    }

}
